Sound Field Synthesis Toolbox for Python
========================================

The Sound Field Synthesis Toolbox for Python gives you the possibility to create
numercial simulations of sound field synthesis methods like wave field synthesis
(WFS) or near-field compensated higher order Ambisonics (NFC-HOA).

Theory:
    http://sfstoolbox.org/

Documentation:
    http://python.sfstoolbox.org/

Source code and issue tracker:
    https://github.com/sfstoolbox/sfs-python/

Python Package Index:
    https://pypi.python.org/pypi/sfs/

SFS Toolbox for Matlab:
    http://matlab.sfstoolbox.org/

License:
    MIT -- see the file ``LICENSE`` for details.

Quick start:
    * Install NumPy, SciPy and Matplotlib
    * ``python3 -m pip install sfs --user``
    * ``python3 doc/examples/horizontal_plane_arrays.py``
